from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.System.Update
import win32more.Windows.Win32.System.WinRT
class ISystemUpdateItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Update.ISystemUpdateItem'
    _iid_ = Guid('{779740eb-5624-519e-a8e2-09e9173b3fb7}')
    @winrt_commethod(6)
    def get_State(self) -> win32more.Windows.System.Update.SystemUpdateItemState: ...
    @winrt_commethod(7)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Description(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Revision(self) -> UInt32: ...
    @winrt_commethod(11)
    def get_DownloadProgress(self) -> Double: ...
    @winrt_commethod(12)
    def get_InstallProgress(self) -> Double: ...
    @winrt_commethod(13)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    Description = property(get_Description, None)
    DownloadProgress = property(get_DownloadProgress, None)
    ExtendedError = property(get_ExtendedError, None)
    Id = property(get_Id, None)
    InstallProgress = property(get_InstallProgress, None)
    Revision = property(get_Revision, None)
    State = property(get_State, None)
    Title = property(get_Title, None)
class ISystemUpdateLastErrorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Update.ISystemUpdateLastErrorInfo'
    _iid_ = Guid('{7ee887f7-8a44-5b6e-bd07-7aece4116ea9}')
    @winrt_commethod(6)
    def get_State(self) -> win32more.Windows.System.Update.SystemUpdateManagerState: ...
    @winrt_commethod(7)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(8)
    def get_IsInteractive(self) -> Boolean: ...
    ExtendedError = property(get_ExtendedError, None)
    IsInteractive = property(get_IsInteractive, None)
    State = property(get_State, None)
class ISystemUpdateManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Update.ISystemUpdateManagerStatics'
    _iid_ = Guid('{b2d3fcef-2971-51be-b41a-8bd703bb701a}')
    @winrt_commethod(6)
    def IsSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_State(self) -> win32more.Windows.System.Update.SystemUpdateManagerState: ...
    @winrt_commethod(8)
    def add_StateChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_StateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_DownloadProgress(self) -> Double: ...
    @winrt_commethod(11)
    def get_InstallProgress(self) -> Double: ...
    @winrt_commethod(12)
    def get_UserActiveHoursStart(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(13)
    def get_UserActiveHoursEnd(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(14)
    def get_UserActiveHoursMax(self) -> Int32: ...
    @winrt_commethod(15)
    def TrySetUserActiveHours(self, start: win32more.Windows.Foundation.TimeSpan, end: win32more.Windows.Foundation.TimeSpan) -> Boolean: ...
    @winrt_commethod(16)
    def get_LastUpdateCheckTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(17)
    def get_LastUpdateInstallTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(18)
    def get_LastErrorInfo(self) -> win32more.Windows.System.Update.SystemUpdateLastErrorInfo: ...
    @winrt_commethod(19)
    def GetAutomaticRebootBlockIds(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(20)
    def BlockAutomaticRebootAsync(self, lockId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(21)
    def UnblockAutomaticRebootAsync(self, lockId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(22)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(23)
    def GetUpdateItems(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.System.Update.SystemUpdateItem]: ...
    @winrt_commethod(24)
    def get_AttentionRequiredReason(self) -> win32more.Windows.System.Update.SystemUpdateAttentionRequiredReason: ...
    @winrt_commethod(25)
    def SetFlightRing(self, flightRing: WinRT_String) -> Boolean: ...
    @winrt_commethod(26)
    def GetFlightRing(self) -> WinRT_String: ...
    @winrt_commethod(27)
    def StartInstall(self, action: win32more.Windows.System.Update.SystemUpdateStartInstallAction) -> Void: ...
    @winrt_commethod(28)
    def RebootToCompleteInstall(self) -> Void: ...
    @winrt_commethod(29)
    def StartCancelUpdates(self) -> Void: ...
    AttentionRequiredReason = property(get_AttentionRequiredReason, None)
    DownloadProgress = property(get_DownloadProgress, None)
    ExtendedError = property(get_ExtendedError, None)
    InstallProgress = property(get_InstallProgress, None)
    LastErrorInfo = property(get_LastErrorInfo, None)
    LastUpdateCheckTime = property(get_LastUpdateCheckTime, None)
    LastUpdateInstallTime = property(get_LastUpdateInstallTime, None)
    State = property(get_State, None)
    UserActiveHoursEnd = property(get_UserActiveHoursEnd, None)
    UserActiveHoursMax = property(get_UserActiveHoursMax, None)
    UserActiveHoursStart = property(get_UserActiveHoursStart, None)
    StateChanged = event()
class SystemUpdateAttentionRequiredReason(Enum, Int32):
    None_ = 0
    NetworkRequired = 1
    InsufficientDiskSpace = 2
    InsufficientBattery = 3
    UpdateBlocked = 4
class SystemUpdateItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Update.ISystemUpdateItem
    _classid_ = 'Windows.System.Update.SystemUpdateItem'
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.System.Update.ISystemUpdateItem) -> win32more.Windows.System.Update.SystemUpdateItemState: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.System.Update.ISystemUpdateItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.System.Update.ISystemUpdateItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.System.Update.ISystemUpdateItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Revision(self: win32more.Windows.System.Update.ISystemUpdateItem) -> UInt32: ...
    @winrt_mixinmethod
    def get_DownloadProgress(self: win32more.Windows.System.Update.ISystemUpdateItem) -> Double: ...
    @winrt_mixinmethod
    def get_InstallProgress(self: win32more.Windows.System.Update.ISystemUpdateItem) -> Double: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Windows.System.Update.ISystemUpdateItem) -> win32more.Windows.Foundation.HResult: ...
    Description = property(get_Description, None)
    DownloadProgress = property(get_DownloadProgress, None)
    ExtendedError = property(get_ExtendedError, None)
    Id = property(get_Id, None)
    InstallProgress = property(get_InstallProgress, None)
    Revision = property(get_Revision, None)
    State = property(get_State, None)
    Title = property(get_Title, None)
class SystemUpdateItemState(Enum, Int32):
    NotStarted = 0
    Initializing = 1
    Preparing = 2
    Calculating = 3
    Downloading = 4
    Installing = 5
    Completed = 6
    RebootRequired = 7
    Error = 8
class SystemUpdateLastErrorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Update.ISystemUpdateLastErrorInfo
    _classid_ = 'Windows.System.Update.SystemUpdateLastErrorInfo'
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.System.Update.ISystemUpdateLastErrorInfo) -> win32more.Windows.System.Update.SystemUpdateManagerState: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Windows.System.Update.ISystemUpdateLastErrorInfo) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_IsInteractive(self: win32more.Windows.System.Update.ISystemUpdateLastErrorInfo) -> Boolean: ...
    ExtendedError = property(get_ExtendedError, None)
    IsInteractive = property(get_IsInteractive, None)
    State = property(get_State, None)
class _SystemUpdateManager_Meta_(ComPtr.__class__):
    pass
class SystemUpdateManager(ComPtr, metaclass=_SystemUpdateManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Update.SystemUpdateManager'
    @winrt_classmethod
    def IsSupported(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> Boolean: ...
    @winrt_classmethod
    def get_State(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.System.Update.SystemUpdateManagerState: ...
    @winrt_classmethod
    def add_StateChanged(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_StateChanged(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_DownloadProgress(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> Double: ...
    @winrt_classmethod
    def get_InstallProgress(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> Double: ...
    @winrt_classmethod
    def get_UserActiveHoursStart(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_classmethod
    def get_UserActiveHoursEnd(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_classmethod
    def get_UserActiveHoursMax(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> Int32: ...
    @winrt_classmethod
    def TrySetUserActiveHours(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics, start: win32more.Windows.Foundation.TimeSpan, end: win32more.Windows.Foundation.TimeSpan) -> Boolean: ...
    @winrt_classmethod
    def get_LastUpdateCheckTime(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_classmethod
    def get_LastUpdateInstallTime(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_classmethod
    def get_LastErrorInfo(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.System.Update.SystemUpdateLastErrorInfo: ...
    @winrt_classmethod
    def GetAutomaticRebootBlockIds(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_classmethod
    def BlockAutomaticRebootAsync(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics, lockId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def UnblockAutomaticRebootAsync(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics, lockId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def get_ExtendedError(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.Foundation.HResult: ...
    @winrt_classmethod
    def GetUpdateItems(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.System.Update.SystemUpdateItem]: ...
    @winrt_classmethod
    def get_AttentionRequiredReason(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> win32more.Windows.System.Update.SystemUpdateAttentionRequiredReason: ...
    @winrt_classmethod
    def SetFlightRing(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics, flightRing: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def GetFlightRing(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> WinRT_String: ...
    @winrt_classmethod
    def StartInstall(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics, action: win32more.Windows.System.Update.SystemUpdateStartInstallAction) -> Void: ...
    @winrt_classmethod
    def RebootToCompleteInstall(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> Void: ...
    @winrt_classmethod
    def StartCancelUpdates(cls: win32more.Windows.System.Update.ISystemUpdateManagerStatics) -> Void: ...
    _SystemUpdateManager_Meta_.AttentionRequiredReason = property(get_AttentionRequiredReason, None)
    _SystemUpdateManager_Meta_.DownloadProgress = property(get_DownloadProgress, None)
    _SystemUpdateManager_Meta_.ExtendedError = property(get_ExtendedError, None)
    _SystemUpdateManager_Meta_.InstallProgress = property(get_InstallProgress, None)
    _SystemUpdateManager_Meta_.LastErrorInfo = property(get_LastErrorInfo, None)
    _SystemUpdateManager_Meta_.LastUpdateCheckTime = property(get_LastUpdateCheckTime, None)
    _SystemUpdateManager_Meta_.LastUpdateInstallTime = property(get_LastUpdateInstallTime, None)
    _SystemUpdateManager_Meta_.State = property(get_State, None)
    _SystemUpdateManager_Meta_.UserActiveHoursEnd = property(get_UserActiveHoursEnd, None)
    _SystemUpdateManager_Meta_.UserActiveHoursMax = property(get_UserActiveHoursMax, None)
    _SystemUpdateManager_Meta_.UserActiveHoursStart = property(get_UserActiveHoursStart, None)
class SystemUpdateManagerState(Enum, Int32):
    Idle = 0
    Detecting = 1
    ReadyToDownload = 2
    Downloading = 3
    ReadyToInstall = 4
    Installing = 5
    RebootRequired = 6
    ReadyToFinalize = 7
    Finalizing = 8
    Completed = 9
    AttentionRequired = 10
    Error = 11
class SystemUpdateStartInstallAction(Enum, Int32):
    UpToReboot = 0
    AllowReboot = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.System.Search.Common
CONDITION_OPERATION = Int32
COP_IMPLICIT: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 0
COP_EQUAL: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 1
COP_NOTEQUAL: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 2
COP_LESSTHAN: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 3
COP_GREATERTHAN: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 4
COP_LESSTHANOREQUAL: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 5
COP_GREATERTHANOREQUAL: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 6
COP_VALUE_STARTSWITH: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 7
COP_VALUE_ENDSWITH: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 8
COP_VALUE_CONTAINS: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 9
COP_VALUE_NOTCONTAINS: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 10
COP_DOSWILDCARDS: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 11
COP_WORD_EQUAL: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 12
COP_WORD_STARTSWITH: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 13
COP_APPLICATION_SPECIFIC: win32more.Windows.Win32.System.Search.Common.CONDITION_OPERATION = 14
CONDITION_TYPE = Int32
CT_AND_CONDITION: win32more.Windows.Win32.System.Search.Common.CONDITION_TYPE = 0
CT_OR_CONDITION: win32more.Windows.Win32.System.Search.Common.CONDITION_TYPE = 1
CT_NOT_CONDITION: win32more.Windows.Win32.System.Search.Common.CONDITION_TYPE = 2
CT_LEAF_CONDITION: win32more.Windows.Win32.System.Search.Common.CONDITION_TYPE = 3


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.System.Diagnostics.Telemetry
import win32more.Windows.Win32.System.WinRT
class IPlatformTelemetryClientStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.Telemetry.IPlatformTelemetryClientStatics'
    _iid_ = Guid('{9bf3f25d-d5c3-4eea-8dbe-9c8dbb0d9d8f}')
    @winrt_commethod(6)
    def Register(self, id: WinRT_String) -> win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationResult: ...
    @winrt_commethod(7)
    def RegisterWithSettings(self, id: WinRT_String, settings: win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationSettings) -> win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationResult: ...
class IPlatformTelemetryRegistrationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.Telemetry.IPlatformTelemetryRegistrationResult'
    _iid_ = Guid('{4d8518ab-2292-49bd-a15a-3d71d2145112}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationStatus: ...
    Status = property(get_Status, None)
class IPlatformTelemetryRegistrationSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.Telemetry.IPlatformTelemetryRegistrationSettings'
    _iid_ = Guid('{819a8582-ca19-415e-bb79-9c224bfa3a73}')
    @winrt_commethod(6)
    def get_StorageSize(self) -> UInt32: ...
    @winrt_commethod(7)
    def put_StorageSize(self, value: UInt32) -> Void: ...
    @winrt_commethod(8)
    def get_UploadQuotaSize(self) -> UInt32: ...
    @winrt_commethod(9)
    def put_UploadQuotaSize(self, value: UInt32) -> Void: ...
    StorageSize = property(get_StorageSize, put_StorageSize)
    UploadQuotaSize = property(get_UploadQuotaSize, put_UploadQuotaSize)
class PlatformTelemetryClient(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Diagnostics.Telemetry.PlatformTelemetryClient'
    @winrt_classmethod
    def Register(cls: win32more.Windows.System.Diagnostics.Telemetry.IPlatformTelemetryClientStatics, id: WinRT_String) -> win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationResult: ...
    @winrt_classmethod
    def RegisterWithSettings(cls: win32more.Windows.System.Diagnostics.Telemetry.IPlatformTelemetryClientStatics, id: WinRT_String, settings: win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationSettings) -> win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationResult: ...
class PlatformTelemetryRegistrationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.Telemetry.IPlatformTelemetryRegistrationResult
    _classid_ = 'Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.System.Diagnostics.Telemetry.IPlatformTelemetryRegistrationResult) -> win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationStatus: ...
    Status = property(get_Status, None)
class PlatformTelemetryRegistrationSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Diagnostics.Telemetry.IPlatformTelemetryRegistrationSettings
    _classid_ = 'Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationSettings.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.System.Diagnostics.Telemetry.PlatformTelemetryRegistrationSettings: ...
    @winrt_mixinmethod
    def get_StorageSize(self: win32more.Windows.System.Diagnostics.Telemetry.IPlatformTelemetryRegistrationSettings) -> UInt32: ...
    @winrt_mixinmethod
    def put_StorageSize(self: win32more.Windows.System.Diagnostics.Telemetry.IPlatformTelemetryRegistrationSettings, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_UploadQuotaSize(self: win32more.Windows.System.Diagnostics.Telemetry.IPlatformTelemetryRegistrationSettings) -> UInt32: ...
    @winrt_mixinmethod
    def put_UploadQuotaSize(self: win32more.Windows.System.Diagnostics.Telemetry.IPlatformTelemetryRegistrationSettings, value: UInt32) -> Void: ...
    StorageSize = property(get_StorageSize, put_StorageSize)
    UploadQuotaSize = property(get_UploadQuotaSize, put_UploadQuotaSize)
class PlatformTelemetryRegistrationStatus(Enum, Int32):
    Success = 0
    SettingsOutOfRange = 1
    UnknownFailure = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.StructuredStorage
import win32more.Windows.Win32.System.Com.UI
import win32more.Windows.Win32.UI.WindowsAndMessaging
class IDummyHICONIncluder(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{947990de-cc28-11d2-a0f7-00805f858fb1}')
    @commethod(3)
    def Dummy(self, h1: win32more.Windows.Win32.UI.WindowsAndMessaging.HICON, h2: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IThumbnailExtractor(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{969dc708-5c76-11d1-8d86-0000f804b057}')
    @commethod(3)
    def ExtractThumbnail(self, pStg: win32more.Windows.Win32.System.Com.StructuredStorage.IStorage, ulLength: UInt32, ulHeight: UInt32, pulOutputLength: POINTER(UInt32), pulOutputHeight: POINTER(UInt32), phOutputBitmap: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnFileUpdated(self, pStg: win32more.Windows.Win32.System.Com.StructuredStorage.IStorage) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Appointments
import win32more.Windows.ApplicationModel.Appointments.DataProvider
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class AppointmentCalendarCancelMeetingRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCancelMeetingRequest'
    @winrt_mixinmethod
    def get_AppointmentCalendarLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppointmentLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppointmentOriginalStartTime(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_Subject(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Comment(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_NotifyInvitees(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest) -> Boolean: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    AppointmentLocalId = property(get_AppointmentLocalId, None)
    AppointmentOriginalStartTime = property(get_AppointmentOriginalStartTime, None)
    Comment = property(get_Comment, None)
    NotifyInvitees = property(get_NotifyInvitees, None)
    Subject = property(get_Subject, None)
class AppointmentCalendarCancelMeetingRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCancelMeetingRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequestEventArgs) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCancelMeetingRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class AppointmentCalendarCreateOrUpdateAppointmentRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequest
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCreateOrUpdateAppointmentRequest'
    @winrt_mixinmethod
    def get_AppointmentCalendarLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Appointment(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequest) -> win32more.Windows.ApplicationModel.Appointments.Appointment: ...
    @winrt_mixinmethod
    def get_NotifyInvitees(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequest) -> Boolean: ...
    @winrt_mixinmethod
    def get_ChangedProperties(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequest) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequest, createdOrUpdatedAppointment: win32more.Windows.ApplicationModel.Appointments.Appointment) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    Appointment = property(get_Appointment, None)
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    ChangedProperties = property(get_ChangedProperties, None)
    NotifyInvitees = property(get_NotifyInvitees, None)
class AppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCreateOrUpdateAppointmentRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class AppointmentCalendarForwardMeetingRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarForwardMeetingRequest'
    @winrt_mixinmethod
    def get_AppointmentCalendarLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppointmentLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppointmentOriginalStartTime(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_Invitees(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Appointments.AppointmentInvitee]: ...
    @winrt_mixinmethod
    def get_Subject(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ForwardHeader(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Comment(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    AppointmentLocalId = property(get_AppointmentLocalId, None)
    AppointmentOriginalStartTime = property(get_AppointmentOriginalStartTime, None)
    Comment = property(get_Comment, None)
    ForwardHeader = property(get_ForwardHeader, None)
    Invitees = property(get_Invitees, None)
    Subject = property(get_Subject, None)
class AppointmentCalendarForwardMeetingRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarForwardMeetingRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequestEventArgs) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarForwardMeetingRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class AppointmentCalendarProposeNewTimeForMeetingRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarProposeNewTimeForMeetingRequest'
    @winrt_mixinmethod
    def get_AppointmentCalendarLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppointmentLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppointmentOriginalStartTime(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_NewStartTime(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_NewDuration(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_Subject(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Comment(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    AppointmentLocalId = property(get_AppointmentLocalId, None)
    AppointmentOriginalStartTime = property(get_AppointmentOriginalStartTime, None)
    Comment = property(get_Comment, None)
    NewDuration = property(get_NewDuration, None)
    NewStartTime = property(get_NewStartTime, None)
    Subject = property(get_Subject, None)
class AppointmentCalendarProposeNewTimeForMeetingRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarProposeNewTimeForMeetingRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequestEventArgs) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarProposeNewTimeForMeetingRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class AppointmentCalendarSyncManagerSyncRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarSyncManagerSyncRequest
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarSyncManagerSyncRequest'
    @winrt_mixinmethod
    def get_AppointmentCalendarLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarSyncManagerSyncRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarSyncManagerSyncRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarSyncManagerSyncRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
class AppointmentCalendarSyncManagerSyncRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarSyncManagerSyncRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarSyncManagerSyncRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarSyncManagerSyncRequestEventArgs) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarSyncManagerSyncRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarSyncManagerSyncRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class AppointmentCalendarUpdateMeetingResponseRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarUpdateMeetingResponseRequest'
    @winrt_mixinmethod
    def get_AppointmentCalendarLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppointmentLocalId(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AppointmentOriginalStartTime(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def get_Response(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest) -> win32more.Windows.ApplicationModel.Appointments.AppointmentParticipantResponse: ...
    @winrt_mixinmethod
    def get_Subject(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Comment(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SendUpdate(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest) -> Boolean: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    AppointmentLocalId = property(get_AppointmentLocalId, None)
    AppointmentOriginalStartTime = property(get_AppointmentOriginalStartTime, None)
    Comment = property(get_Comment, None)
    Response = property(get_Response, None)
    SendUpdate = property(get_SendUpdate, None)
    Subject = property(get_Subject, None)
class AppointmentCalendarUpdateMeetingResponseRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarUpdateMeetingResponseRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequestEventArgs) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarUpdateMeetingResponseRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class AppointmentDataProviderConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection'
    @winrt_mixinmethod
    def add_SyncRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarSyncManagerSyncRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SyncRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CreateOrUpdateAppointmentRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CreateOrUpdateAppointmentRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CancelMeetingRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCancelMeetingRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CancelMeetingRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ForwardMeetingRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarForwardMeetingRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ForwardMeetingRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ProposeNewTimeForMeetingRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarProposeNewTimeForMeetingRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ProposeNewTimeForMeetingRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UpdateMeetingResponseRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarUpdateMeetingResponseRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UpdateMeetingResponseRequested(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Start(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection) -> Void: ...
    SyncRequested = event()
    CreateOrUpdateAppointmentRequested = event()
    CancelMeetingRequested = event()
    ForwardMeetingRequested = event()
    ProposeNewTimeForMeetingRequested = event()
    UpdateMeetingResponseRequested = event()
class AppointmentDataProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderTriggerDetails
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderTriggerDetails'
    @winrt_mixinmethod
    def get_Connection(self: win32more.Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderTriggerDetails) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection: ...
    Connection = property(get_Connection, None)
class IAppointmentCalendarCancelMeetingRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequest'
    _iid_ = Guid('{49460f8d-6434-40d7-ad46-6297419314d1}')
    @winrt_commethod(6)
    def get_AppointmentCalendarLocalId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_AppointmentLocalId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_AppointmentOriginalStartTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(9)
    def get_Subject(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Comment(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_NotifyInvitees(self) -> Boolean: ...
    @winrt_commethod(12)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(13)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    AppointmentLocalId = property(get_AppointmentLocalId, None)
    AppointmentOriginalStartTime = property(get_AppointmentOriginalStartTime, None)
    Comment = property(get_Comment, None)
    NotifyInvitees = property(get_NotifyInvitees, None)
    Subject = property(get_Subject, None)
class IAppointmentCalendarCancelMeetingRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCancelMeetingRequestEventArgs'
    _iid_ = Guid('{1a79be16-7f30-4e35-beef-9d2c7b6dcae1}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCancelMeetingRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IAppointmentCalendarCreateOrUpdateAppointmentRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequest'
    _iid_ = Guid('{2e62f2b2-ca96-48ac-9124-406b19fefa70}')
    @winrt_commethod(6)
    def get_AppointmentCalendarLocalId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Appointment(self) -> win32more.Windows.ApplicationModel.Appointments.Appointment: ...
    @winrt_commethod(8)
    def get_NotifyInvitees(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_ChangedProperties(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(10)
    def ReportCompletedAsync(self, createdOrUpdatedAppointment: win32more.Windows.ApplicationModel.Appointments.Appointment) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(11)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    Appointment = property(get_Appointment, None)
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    ChangedProperties = property(get_ChangedProperties, None)
    NotifyInvitees = property(get_NotifyInvitees, None)
class IAppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs'
    _iid_ = Guid('{cf8ded28-002e-4bf7-8e9d-5e20d49aa3ba}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCreateOrUpdateAppointmentRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IAppointmentCalendarForwardMeetingRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequest'
    _iid_ = Guid('{82e5ee56-26b6-4253-8a8f-6cf5f2ff7884}')
    @winrt_commethod(6)
    def get_AppointmentCalendarLocalId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_AppointmentLocalId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_AppointmentOriginalStartTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(9)
    def get_Invitees(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Appointments.AppointmentInvitee]: ...
    @winrt_commethod(10)
    def get_Subject(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_ForwardHeader(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_Comment(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(14)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    AppointmentLocalId = property(get_AppointmentLocalId, None)
    AppointmentOriginalStartTime = property(get_AppointmentOriginalStartTime, None)
    Comment = property(get_Comment, None)
    ForwardHeader = property(get_ForwardHeader, None)
    Invitees = property(get_Invitees, None)
    Subject = property(get_Subject, None)
class IAppointmentCalendarForwardMeetingRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarForwardMeetingRequestEventArgs'
    _iid_ = Guid('{3109151a-23a2-42fd-9c82-c9a60d59f8a8}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarForwardMeetingRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IAppointmentCalendarProposeNewTimeForMeetingRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequest'
    _iid_ = Guid('{ce1c63f5-edf6-43c3-82b7-be6b368c6900}')
    @winrt_commethod(6)
    def get_AppointmentCalendarLocalId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_AppointmentLocalId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_AppointmentOriginalStartTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(9)
    def get_NewStartTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(10)
    def get_NewDuration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(11)
    def get_Subject(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_Comment(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(14)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    AppointmentLocalId = property(get_AppointmentLocalId, None)
    AppointmentOriginalStartTime = property(get_AppointmentOriginalStartTime, None)
    Comment = property(get_Comment, None)
    NewDuration = property(get_NewDuration, None)
    NewStartTime = property(get_NewStartTime, None)
    Subject = property(get_Subject, None)
class IAppointmentCalendarProposeNewTimeForMeetingRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarProposeNewTimeForMeetingRequestEventArgs'
    _iid_ = Guid('{d2d777d8-fed1-4280-a3ba-2e1f47609aa2}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarProposeNewTimeForMeetingRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IAppointmentCalendarSyncManagerSyncRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarSyncManagerSyncRequest'
    _iid_ = Guid('{12ab382b-7163-4a56-9a4e-7223a84adf46}')
    @winrt_commethod(6)
    def get_AppointmentCalendarLocalId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
class IAppointmentCalendarSyncManagerSyncRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarSyncManagerSyncRequestEventArgs'
    _iid_ = Guid('{ca17c6f7-0284-4edd-87ba-4d8f69dcf5c0}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarSyncManagerSyncRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IAppointmentCalendarUpdateMeetingResponseRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequest'
    _iid_ = Guid('{a36d608c-c29d-4b94-b086-7e9ff7bd84a0}')
    @winrt_commethod(6)
    def get_AppointmentCalendarLocalId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_AppointmentLocalId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_AppointmentOriginalStartTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(9)
    def get_Response(self) -> win32more.Windows.ApplicationModel.Appointments.AppointmentParticipantResponse: ...
    @winrt_commethod(10)
    def get_Subject(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_Comment(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_SendUpdate(self) -> Boolean: ...
    @winrt_commethod(13)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(14)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    AppointmentCalendarLocalId = property(get_AppointmentCalendarLocalId, None)
    AppointmentLocalId = property(get_AppointmentLocalId, None)
    AppointmentOriginalStartTime = property(get_AppointmentOriginalStartTime, None)
    Comment = property(get_Comment, None)
    Response = property(get_Response, None)
    SendUpdate = property(get_SendUpdate, None)
    Subject = property(get_Subject, None)
class IAppointmentCalendarUpdateMeetingResponseRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentCalendarUpdateMeetingResponseRequestEventArgs'
    _iid_ = Guid('{88759883-97bf-479d-aed5-0be8ce567d1e}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarUpdateMeetingResponseRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IAppointmentDataProviderConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderConnection'
    _iid_ = Guid('{f3dd9d83-3254-465f-abdb-928046552cf4}')
    @winrt_commethod(6)
    def add_SyncRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarSyncManagerSyncRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_SyncRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_CreateOrUpdateAppointmentRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCreateOrUpdateAppointmentRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_CreateOrUpdateAppointmentRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_CancelMeetingRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarCancelMeetingRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_CancelMeetingRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_ForwardMeetingRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarForwardMeetingRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_ForwardMeetingRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_ProposeNewTimeForMeetingRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarProposeNewTimeForMeetingRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_ProposeNewTimeForMeetingRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_UpdateMeetingResponseRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection, win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentCalendarUpdateMeetingResponseRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_UpdateMeetingResponseRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def Start(self) -> Void: ...
    SyncRequested = event()
    CreateOrUpdateAppointmentRequested = event()
    CancelMeetingRequested = event()
    ForwardMeetingRequested = event()
    ProposeNewTimeForMeetingRequested = event()
    UpdateMeetingResponseRequested = event()
class IAppointmentDataProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Appointments.DataProvider.IAppointmentDataProviderTriggerDetails'
    _iid_ = Guid('{b3283c01-7e12-4e5e-b1ef-74fb68ac6f2a}')
    @winrt_commethod(6)
    def get_Connection(self) -> win32more.Windows.ApplicationModel.Appointments.DataProvider.AppointmentDataProviderConnection: ...
    Connection = property(get_Connection, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security.Cryptography
import win32more.Windows.Win32.Security.Cryptography.Catalog
import win32more.Windows.Win32.Security.Cryptography.Sip
MSSIP_FLAGS_PROHIBIT_RESIZE_ON_CREATE: UInt32 = 65536
MSSIP_FLAGS_USE_CATALOG: UInt32 = 131072
MSSIP_FLAGS_MULTI_HASH: UInt32 = 262144
SPC_RELAXED_PE_MARKER_CHECK: UInt32 = 2048
SPC_MARKER_CHECK_SKIP_SIP_INDIRECT_DATA_FLAG: UInt32 = 1
SPC_MARKER_CHECK_CURRENTLY_SUPPORTED_FLAGS: UInt32 = 1
MSSIP_ADDINFO_NONE: UInt32 = 0
MSSIP_ADDINFO_FLAT: UInt32 = 1
MSSIP_ADDINFO_CATMEMBER: UInt32 = 2
MSSIP_ADDINFO_BLOB: UInt32 = 3
MSSIP_ADDINFO_NONMSSIP: UInt32 = 500
SIP_CAP_SET_VERSION_2: UInt32 = 2
SIP_CAP_SET_VERSION_3: UInt32 = 3
SIP_CAP_SET_CUR_VER: UInt32 = 3
SIP_CAP_FLAG_SEALING: UInt32 = 1
SIP_MAX_MAGIC_NUMBER: UInt32 = 4
@winfunctype('WINTRUST.dll')
def CryptSIPGetSignedDataMsg(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pdwEncodingType: POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_QUERY_ENCODING_TYPE), dwIndex: UInt32, pcbSignedDataMsg: POINTER(UInt32), pbSignedDataMsg: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptSIPPutSignedDataMsg(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), dwEncodingType: win32more.Windows.Win32.Security.Cryptography.CERT_QUERY_ENCODING_TYPE, pdwIndex: POINTER(UInt32), cbSignedDataMsg: UInt32, pbSignedDataMsg: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptSIPCreateIndirectData(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pcbIndirectData: POINTER(UInt32), pIndirectData: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_INDIRECT_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptSIPVerifyIndirectData(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pIndirectData: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_INDIRECT_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptSIPRemoveSignedDataMsg(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), dwIndex: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CRYPT32.dll')
def CryptSIPLoad(pgSubject: POINTER(Guid), dwFlags: UInt32, pSipDispatch: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_DISPATCH_INFO)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CRYPT32.dll')
def CryptSIPRetrieveSubjectGuid(FileName: win32more.Windows.Win32.Foundation.PWSTR, hFileIn: win32more.Windows.Win32.Foundation.HANDLE, pgSubject: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CRYPT32.dll')
def CryptSIPRetrieveSubjectGuidForCatalogFile(FileName: win32more.Windows.Win32.Foundation.PWSTR, hFileIn: win32more.Windows.Win32.Foundation.HANDLE, pgSubject: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CRYPT32.dll')
def CryptSIPAddProvider(psNewProv: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_ADD_NEWPROVIDER)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('CRYPT32.dll')
def CryptSIPRemoveProvider(pgProv: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptSIPGetCaps(pSubjInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pCaps: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_CAP_SET_V3)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('WINTRUST.dll')
def CryptSIPGetSealedDigest(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pSig: POINTER(Byte), dwSig: UInt32, pbDigest: POINTER(Byte), pcbDigest: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class MS_ADDINFO_BLOB(Structure):
    cbStruct: UInt32
    cbMemObject: UInt32
    pbMemObject: POINTER(Byte)
    cbMemSignedMsg: UInt32
    pbMemSignedMsg: POINTER(Byte)
class MS_ADDINFO_FLAT(Structure):
    cbStruct: UInt32
    pIndirectData: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_INDIRECT_DATA)
class SIP_ADD_NEWPROVIDER(Structure):
    cbStruct: UInt32
    pgSubject: POINTER(Guid)
    pwszDLLFileName: win32more.Windows.Win32.Foundation.PWSTR
    pwszMagicNumber: win32more.Windows.Win32.Foundation.PWSTR
    pwszIsFunctionName: win32more.Windows.Win32.Foundation.PWSTR
    pwszGetFuncName: win32more.Windows.Win32.Foundation.PWSTR
    pwszPutFuncName: win32more.Windows.Win32.Foundation.PWSTR
    pwszCreateFuncName: win32more.Windows.Win32.Foundation.PWSTR
    pwszVerifyFuncName: win32more.Windows.Win32.Foundation.PWSTR
    pwszRemoveFuncName: win32more.Windows.Win32.Foundation.PWSTR
    pwszIsFunctionNameFmt2: win32more.Windows.Win32.Foundation.PWSTR
    pwszGetCapFuncName: win32more.Windows.Win32.Foundation.PWSTR
class SIP_CAP_SET_V2(Structure):
    cbSize: UInt32
    dwVersion: UInt32
    isMultiSign: win32more.Windows.Win32.Foundation.BOOL
    dwReserved: UInt32
class SIP_CAP_SET_V3(Structure):
    cbSize: UInt32
    dwVersion: UInt32
    isMultiSign: win32more.Windows.Win32.Foundation.BOOL
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        dwFlags: UInt32
        dwReserved: UInt32
class SIP_DISPATCH_INFO(Structure):
    cbSize: UInt32
    hSIP: win32more.Windows.Win32.Foundation.HANDLE
    pfGet: win32more.Windows.Win32.Security.Cryptography.Sip.pCryptSIPGetSignedDataMsg
    pfPut: win32more.Windows.Win32.Security.Cryptography.Sip.pCryptSIPPutSignedDataMsg
    pfCreate: win32more.Windows.Win32.Security.Cryptography.Sip.pCryptSIPCreateIndirectData
    pfVerify: win32more.Windows.Win32.Security.Cryptography.Sip.pCryptSIPVerifyIndirectData
    pfRemove: win32more.Windows.Win32.Security.Cryptography.Sip.pCryptSIPRemoveSignedDataMsg
class SIP_INDIRECT_DATA(Structure):
    Data: win32more.Windows.Win32.Security.Cryptography.CRYPT_ATTRIBUTE_TYPE_VALUE
    DigestAlgorithm: win32more.Windows.Win32.Security.Cryptography.CRYPT_ALGORITHM_IDENTIFIER
    Digest: win32more.Windows.Win32.Security.Cryptography.CRYPT_INTEGER_BLOB
class SIP_SUBJECTINFO(Structure):
    cbSize: UInt32
    pgSubjectType: POINTER(Guid)
    hFile: win32more.Windows.Win32.Foundation.HANDLE
    pwsFileName: win32more.Windows.Win32.Foundation.PWSTR
    pwsDisplayName: win32more.Windows.Win32.Foundation.PWSTR
    dwReserved1: UInt32
    dwIntVersion: UInt32
    hProv: UIntPtr
    DigestAlgorithm: win32more.Windows.Win32.Security.Cryptography.CRYPT_ALGORITHM_IDENTIFIER
    dwFlags: UInt32
    dwEncodingType: UInt32
    dwReserved2: UInt32
    fdwCAPISettings: UInt32
    fdwSecuritySettings: UInt32
    dwIndex: UInt32
    dwUnionChoice: UInt32
    Anonymous: _Anonymous_e__Union
    pClientData: VoidPtr
    class _Anonymous_e__Union(Union):
        psFlat: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.MS_ADDINFO_FLAT)
        psCatMember: POINTER(win32more.Windows.Win32.Security.Cryptography.Catalog.MS_ADDINFO_CATALOGMEMBER)
        psBlob: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.MS_ADDINFO_BLOB)
@winfunctype_pointer
def pCryptSIPCreateIndirectData(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pcbIndirectData: POINTER(UInt32), pIndirectData: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_INDIRECT_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pCryptSIPGetCaps(pSubjInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pCaps: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_CAP_SET_V3)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pCryptSIPGetSealedDigest(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pSig: POINTER(Byte), dwSig: UInt32, pbDigest: POINTER(Byte), pcbDigest: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pCryptSIPGetSignedDataMsg(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pdwEncodingType: POINTER(UInt32), dwIndex: UInt32, pcbSignedDataMsg: POINTER(UInt32), pbSignedDataMsg: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pCryptSIPPutSignedDataMsg(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), dwEncodingType: UInt32, pdwIndex: POINTER(UInt32), cbSignedDataMsg: UInt32, pbSignedDataMsg: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pCryptSIPRemoveSignedDataMsg(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), dwIndex: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pCryptSIPVerifyIndirectData(pSubjectInfo: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_SUBJECTINFO), pIndirectData: POINTER(win32more.Windows.Win32.Security.Cryptography.Sip.SIP_INDIRECT_DATA)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pfnIsFileSupported(hFile: win32more.Windows.Win32.Foundation.HANDLE, pgSubject: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def pfnIsFileSupportedName(pwszFileName: win32more.Windows.Win32.Foundation.PWSTR, pgSubject: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.BOOL: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Lights
import win32more.Windows.Devices.Lights.Effects
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.Imaging
import win32more.Windows.UI
import win32more.Windows.Win32.System.WinRT
class ILampArrayBitmapEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayBitmapEffect'
    _iid_ = Guid('{3238e065-d877-4627-89e5-2a88f7052fa6}')
    @winrt_commethod(6)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def put_Duration(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(8)
    def get_StartDelay(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def put_StartDelay(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(10)
    def get_UpdateInterval(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(11)
    def put_UpdateInterval(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(12)
    def get_SuggestedBitmapSize(self) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(13)
    def add_BitmapRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Lights.Effects.LampArrayBitmapEffect, win32more.Windows.Devices.Lights.Effects.LampArrayBitmapRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_BitmapRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Duration = property(get_Duration, put_Duration)
    StartDelay = property(get_StartDelay, put_StartDelay)
    SuggestedBitmapSize = property(get_SuggestedBitmapSize, None)
    UpdateInterval = property(get_UpdateInterval, put_UpdateInterval)
    BitmapRequested = event()
class ILampArrayBitmapEffectFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayBitmapEffectFactory'
    _iid_ = Guid('{13608090-e336-4c8f-9053-a92407ca7b1d}')
    @winrt_commethod(6)
    def CreateInstance(self, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArrayBitmapEffect: ...
class ILampArrayBitmapRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayBitmapRequestedEventArgs'
    _iid_ = Guid('{c8b4af9e-fe63-4d51-babd-619defb454ba}')
    @winrt_commethod(6)
    def get_SinceStarted(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def UpdateBitmap(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
    SinceStarted = property(get_SinceStarted, None)
class ILampArrayBlinkEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayBlinkEffect'
    _iid_ = Guid('{ebbf35f6-2fc5-4bb3-b3c3-6221a7680d13}')
    @winrt_commethod(6)
    def get_Color(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def put_Color(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(8)
    def get_AttackDuration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def put_AttackDuration(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(10)
    def get_SustainDuration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(11)
    def put_SustainDuration(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(12)
    def get_DecayDuration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(13)
    def put_DecayDuration(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(14)
    def get_RepetitionDelay(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(15)
    def put_RepetitionDelay(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(16)
    def get_StartDelay(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(17)
    def put_StartDelay(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(18)
    def get_Occurrences(self) -> Int32: ...
    @winrt_commethod(19)
    def put_Occurrences(self, value: Int32) -> Void: ...
    @winrt_commethod(20)
    def get_RepetitionMode(self) -> win32more.Windows.Devices.Lights.Effects.LampArrayRepetitionMode: ...
    @winrt_commethod(21)
    def put_RepetitionMode(self, value: win32more.Windows.Devices.Lights.Effects.LampArrayRepetitionMode) -> Void: ...
    AttackDuration = property(get_AttackDuration, put_AttackDuration)
    Color = property(get_Color, put_Color)
    DecayDuration = property(get_DecayDuration, put_DecayDuration)
    Occurrences = property(get_Occurrences, put_Occurrences)
    RepetitionDelay = property(get_RepetitionDelay, put_RepetitionDelay)
    RepetitionMode = property(get_RepetitionMode, put_RepetitionMode)
    StartDelay = property(get_StartDelay, put_StartDelay)
    SustainDuration = property(get_SustainDuration, put_SustainDuration)
class ILampArrayBlinkEffectFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayBlinkEffectFactory'
    _iid_ = Guid('{879f1d97-9f50-49b2-a56f-013aa08d55e0}')
    @winrt_commethod(6)
    def CreateInstance(self, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArrayBlinkEffect: ...
class ILampArrayColorRampEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayColorRampEffect'
    _iid_ = Guid('{2b004437-40a7-432e-a0b9-0d570c2153ff}')
    @winrt_commethod(6)
    def get_Color(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def put_Color(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(8)
    def get_RampDuration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def put_RampDuration(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(10)
    def get_StartDelay(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(11)
    def put_StartDelay(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(12)
    def get_CompletionBehavior(self) -> win32more.Windows.Devices.Lights.Effects.LampArrayEffectCompletionBehavior: ...
    @winrt_commethod(13)
    def put_CompletionBehavior(self, value: win32more.Windows.Devices.Lights.Effects.LampArrayEffectCompletionBehavior) -> Void: ...
    Color = property(get_Color, put_Color)
    CompletionBehavior = property(get_CompletionBehavior, put_CompletionBehavior)
    RampDuration = property(get_RampDuration, put_RampDuration)
    StartDelay = property(get_StartDelay, put_StartDelay)
class ILampArrayColorRampEffectFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayColorRampEffectFactory'
    _iid_ = Guid('{520bd133-0c74-4df5-bea7-4899e0266b0f}')
    @winrt_commethod(6)
    def CreateInstance(self, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArrayColorRampEffect: ...
class ILampArrayCustomEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayCustomEffect'
    _iid_ = Guid('{ec579170-3c34-4876-818b-5765f78b0ee4}')
    @winrt_commethod(6)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def put_Duration(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(8)
    def get_UpdateInterval(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def put_UpdateInterval(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(10)
    def add_UpdateRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Lights.Effects.LampArrayCustomEffect, win32more.Windows.Devices.Lights.Effects.LampArrayUpdateRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_UpdateRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Duration = property(get_Duration, put_Duration)
    UpdateInterval = property(get_UpdateInterval, put_UpdateInterval)
    UpdateRequested = event()
class ILampArrayCustomEffectFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayCustomEffectFactory'
    _iid_ = Guid('{68b4774d-63e5-4af0-a58b-3e535b94e8c9}')
    @winrt_commethod(6)
    def CreateInstance(self, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArrayCustomEffect: ...
class ILampArrayEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayEffect'
    _iid_ = Guid('{11d45590-57fb-4546-b1ce-863107f740df}')
    @winrt_commethod(6)
    def get_ZIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def put_ZIndex(self, value: Int32) -> Void: ...
    ZIndex = property(get_ZIndex, put_ZIndex)
class ILampArrayEffectPlaylist(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist'
    _iid_ = Guid('{7de58bfe-6f61-4103-98c7-d6632f7b9169}')
    @winrt_commethod(6)
    def Append(self, effect: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect) -> Void: ...
    @winrt_commethod(7)
    def OverrideZIndex(self, zIndex: Int32) -> Void: ...
    @winrt_commethod(8)
    def Start(self) -> Void: ...
    @winrt_commethod(9)
    def Stop(self) -> Void: ...
    @winrt_commethod(10)
    def Pause(self) -> Void: ...
    @winrt_commethod(11)
    def get_EffectStartMode(self) -> win32more.Windows.Devices.Lights.Effects.LampArrayEffectStartMode: ...
    @winrt_commethod(12)
    def put_EffectStartMode(self, value: win32more.Windows.Devices.Lights.Effects.LampArrayEffectStartMode) -> Void: ...
    @winrt_commethod(13)
    def get_Occurrences(self) -> Int32: ...
    @winrt_commethod(14)
    def put_Occurrences(self, value: Int32) -> Void: ...
    @winrt_commethod(15)
    def get_RepetitionMode(self) -> win32more.Windows.Devices.Lights.Effects.LampArrayRepetitionMode: ...
    @winrt_commethod(16)
    def put_RepetitionMode(self, value: win32more.Windows.Devices.Lights.Effects.LampArrayRepetitionMode) -> Void: ...
    EffectStartMode = property(get_EffectStartMode, put_EffectStartMode)
    Occurrences = property(get_Occurrences, put_Occurrences)
    RepetitionMode = property(get_RepetitionMode, put_RepetitionMode)
class ILampArrayEffectPlaylistStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayEffectPlaylistStatics'
    _iid_ = Guid('{fb15235c-ea35-4c7f-a016-f3bfc6a6c47d}')
    @winrt_commethod(6)
    def StartAll(self, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Devices.Lights.Effects.LampArrayEffectPlaylist]) -> Void: ...
    @winrt_commethod(7)
    def StopAll(self, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Devices.Lights.Effects.LampArrayEffectPlaylist]) -> Void: ...
    @winrt_commethod(8)
    def PauseAll(self, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Devices.Lights.Effects.LampArrayEffectPlaylist]) -> Void: ...
class ILampArraySolidEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArraySolidEffect'
    _iid_ = Guid('{441f8213-43cc-4b33-80eb-c6ddde7dc8ed}')
    @winrt_commethod(6)
    def get_Color(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(7)
    def put_Color(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(8)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def put_Duration(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(10)
    def get_StartDelay(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(11)
    def put_StartDelay(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_commethod(12)
    def get_CompletionBehavior(self) -> win32more.Windows.Devices.Lights.Effects.LampArrayEffectCompletionBehavior: ...
    @winrt_commethod(13)
    def put_CompletionBehavior(self, value: win32more.Windows.Devices.Lights.Effects.LampArrayEffectCompletionBehavior) -> Void: ...
    Color = property(get_Color, put_Color)
    CompletionBehavior = property(get_CompletionBehavior, put_CompletionBehavior)
    Duration = property(get_Duration, put_Duration)
    StartDelay = property(get_StartDelay, put_StartDelay)
class ILampArraySolidEffectFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArraySolidEffectFactory'
    _iid_ = Guid('{f862a32c-5576-4341-961b-aee1f13cf9dd}')
    @winrt_commethod(6)
    def CreateInstance(self, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArraySolidEffect: ...
class ILampArrayUpdateRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Lights.Effects.ILampArrayUpdateRequestedEventArgs'
    _iid_ = Guid('{73560d6a-576a-48af-8539-67ffa0ab3516}')
    @winrt_commethod(6)
    def get_SinceStarted(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(7)
    def SetColor(self, desiredColor: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(8)
    def SetColorForIndex(self, lampIndex: Int32, desiredColor: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(9)
    def SetSingleColorForIndices(self, desiredColor: win32more.Windows.UI.Color, lampIndexes: PassArray[Int32]) -> Void: ...
    @winrt_commethod(10)
    def SetColorsForIndices(self, desiredColors: PassArray[win32more.Windows.UI.Color], lampIndexes: PassArray[Int32]) -> Void: ...
    SinceStarted = property(get_SinceStarted, None)
class LampArrayBitmapEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect
    _classid_ = 'Windows.Devices.Lights.Effects.LampArrayBitmapEffect'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Devices.Lights.Effects.LampArrayBitmapEffect.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffectFactory, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArrayBitmapEffect: ...
    @winrt_mixinmethod
    def get_Duration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Duration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_StartDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_StartDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_UpdateInterval(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_UpdateInterval(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_SuggestedBitmapSize(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def add_BitmapRequested(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Lights.Effects.LampArrayBitmapEffect, win32more.Windows.Devices.Lights.Effects.LampArrayBitmapRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_BitmapRequested(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapEffect, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect) -> Int32: ...
    @winrt_mixinmethod
    def put_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect, value: Int32) -> Void: ...
    Duration = property(get_Duration, put_Duration)
    StartDelay = property(get_StartDelay, put_StartDelay)
    SuggestedBitmapSize = property(get_SuggestedBitmapSize, None)
    UpdateInterval = property(get_UpdateInterval, put_UpdateInterval)
    ZIndex = property(get_ZIndex, put_ZIndex)
    BitmapRequested = event()
class LampArrayBitmapRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapRequestedEventArgs
    _classid_ = 'Windows.Devices.Lights.Effects.LampArrayBitmapRequestedEventArgs'
    @winrt_mixinmethod
    def get_SinceStarted(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapRequestedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def UpdateBitmap(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBitmapRequestedEventArgs, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> Void: ...
    SinceStarted = property(get_SinceStarted, None)
class LampArrayBlinkEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect
    _classid_ = 'Windows.Devices.Lights.Effects.LampArrayBlinkEffect'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Devices.Lights.Effects.LampArrayBlinkEffect.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffectFactory, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArrayBlinkEffect: ...
    @winrt_mixinmethod
    def get_Color(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_Color(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def get_AttackDuration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_AttackDuration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_SustainDuration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_SustainDuration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_DecayDuration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_DecayDuration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_RepetitionDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_RepetitionDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_StartDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_StartDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_Occurrences(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect) -> Int32: ...
    @winrt_mixinmethod
    def put_Occurrences(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_RepetitionMode(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect) -> win32more.Windows.Devices.Lights.Effects.LampArrayRepetitionMode: ...
    @winrt_mixinmethod
    def put_RepetitionMode(self: win32more.Windows.Devices.Lights.Effects.ILampArrayBlinkEffect, value: win32more.Windows.Devices.Lights.Effects.LampArrayRepetitionMode) -> Void: ...
    @winrt_mixinmethod
    def get_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect) -> Int32: ...
    @winrt_mixinmethod
    def put_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect, value: Int32) -> Void: ...
    AttackDuration = property(get_AttackDuration, put_AttackDuration)
    Color = property(get_Color, put_Color)
    DecayDuration = property(get_DecayDuration, put_DecayDuration)
    Occurrences = property(get_Occurrences, put_Occurrences)
    RepetitionDelay = property(get_RepetitionDelay, put_RepetitionDelay)
    RepetitionMode = property(get_RepetitionMode, put_RepetitionMode)
    StartDelay = property(get_StartDelay, put_StartDelay)
    SustainDuration = property(get_SustainDuration, put_SustainDuration)
    ZIndex = property(get_ZIndex, put_ZIndex)
class LampArrayColorRampEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffect
    _classid_ = 'Windows.Devices.Lights.Effects.LampArrayColorRampEffect'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Devices.Lights.Effects.LampArrayColorRampEffect.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffectFactory, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArrayColorRampEffect: ...
    @winrt_mixinmethod
    def get_Color(self: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffect) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_Color(self: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffect, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def get_RampDuration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_RampDuration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_StartDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_StartDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_CompletionBehavior(self: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffect) -> win32more.Windows.Devices.Lights.Effects.LampArrayEffectCompletionBehavior: ...
    @winrt_mixinmethod
    def put_CompletionBehavior(self: win32more.Windows.Devices.Lights.Effects.ILampArrayColorRampEffect, value: win32more.Windows.Devices.Lights.Effects.LampArrayEffectCompletionBehavior) -> Void: ...
    @winrt_mixinmethod
    def get_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect) -> Int32: ...
    @winrt_mixinmethod
    def put_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect, value: Int32) -> Void: ...
    Color = property(get_Color, put_Color)
    CompletionBehavior = property(get_CompletionBehavior, put_CompletionBehavior)
    RampDuration = property(get_RampDuration, put_RampDuration)
    StartDelay = property(get_StartDelay, put_StartDelay)
    ZIndex = property(get_ZIndex, put_ZIndex)
class LampArrayCustomEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Lights.Effects.ILampArrayCustomEffect
    _classid_ = 'Windows.Devices.Lights.Effects.LampArrayCustomEffect'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Devices.Lights.Effects.LampArrayCustomEffect.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.Devices.Lights.Effects.ILampArrayCustomEffectFactory, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArrayCustomEffect: ...
    @winrt_mixinmethod
    def get_Duration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayCustomEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Duration(self: win32more.Windows.Devices.Lights.Effects.ILampArrayCustomEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_UpdateInterval(self: win32more.Windows.Devices.Lights.Effects.ILampArrayCustomEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_UpdateInterval(self: win32more.Windows.Devices.Lights.Effects.ILampArrayCustomEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def add_UpdateRequested(self: win32more.Windows.Devices.Lights.Effects.ILampArrayCustomEffect, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Lights.Effects.LampArrayCustomEffect, win32more.Windows.Devices.Lights.Effects.LampArrayUpdateRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UpdateRequested(self: win32more.Windows.Devices.Lights.Effects.ILampArrayCustomEffect, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect) -> Int32: ...
    @winrt_mixinmethod
    def put_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect, value: Int32) -> Void: ...
    Duration = property(get_Duration, put_Duration)
    UpdateInterval = property(get_UpdateInterval, put_UpdateInterval)
    ZIndex = property(get_ZIndex, put_ZIndex)
    UpdateRequested = event()
class LampArrayEffectCompletionBehavior(Enum, Int32):
    ClearState = 0
    KeepState = 1
class LampArrayEffectPlaylist(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.Devices.Lights.Effects.ILampArrayEffect]]
    default_interface: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist
    _classid_ = 'Windows.Devices.Lights.Effects.LampArrayEffectPlaylist'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Devices.Lights.Effects.LampArrayEffectPlaylist.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Devices.Lights.Effects.LampArrayEffectPlaylist: ...
    @winrt_mixinmethod
    def Append(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist, effect: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect) -> Void: ...
    @winrt_mixinmethod
    def OverrideZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist, zIndex: Int32) -> Void: ...
    @winrt_mixinmethod
    def Start(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist) -> Void: ...
    @winrt_mixinmethod
    def Pause(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist) -> Void: ...
    @winrt_mixinmethod
    def get_EffectStartMode(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist) -> win32more.Windows.Devices.Lights.Effects.LampArrayEffectStartMode: ...
    @winrt_mixinmethod
    def put_EffectStartMode(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist, value: win32more.Windows.Devices.Lights.Effects.LampArrayEffectStartMode) -> Void: ...
    @winrt_mixinmethod
    def get_Occurrences(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist) -> Int32: ...
    @winrt_mixinmethod
    def put_Occurrences(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_RepetitionMode(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist) -> win32more.Windows.Devices.Lights.Effects.LampArrayRepetitionMode: ...
    @winrt_mixinmethod
    def put_RepetitionMode(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylist, value: win32more.Windows.Devices.Lights.Effects.LampArrayRepetitionMode) -> Void: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Lights.Effects.ILampArrayEffect], index: UInt32) -> win32more.Windows.Devices.Lights.Effects.ILampArrayEffect: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Lights.Effects.ILampArrayEffect]) -> UInt32: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Lights.Effects.ILampArrayEffect], value: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Lights.Effects.ILampArrayEffect], startIndex: UInt32, items: FillArray[win32more.Windows.Devices.Lights.Effects.ILampArrayEffect]) -> UInt32: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Devices.Lights.Effects.ILampArrayEffect]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Devices.Lights.Effects.ILampArrayEffect]: ...
    @winrt_classmethod
    def StartAll(cls: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylistStatics, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Devices.Lights.Effects.LampArrayEffectPlaylist]) -> Void: ...
    @winrt_classmethod
    def StopAll(cls: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylistStatics, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Devices.Lights.Effects.LampArrayEffectPlaylist]) -> Void: ...
    @winrt_classmethod
    def PauseAll(cls: win32more.Windows.Devices.Lights.Effects.ILampArrayEffectPlaylistStatics, value: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Devices.Lights.Effects.LampArrayEffectPlaylist]) -> Void: ...
    EffectStartMode = property(get_EffectStartMode, put_EffectStartMode)
    Occurrences = property(get_Occurrences, put_Occurrences)
    RepetitionMode = property(get_RepetitionMode, put_RepetitionMode)
    Size = property(get_Size, None)
class LampArrayEffectStartMode(Enum, Int32):
    Sequential = 0
    Simultaneous = 1
class LampArrayRepetitionMode(Enum, Int32):
    Occurrences = 0
    Forever = 1
class LampArraySolidEffect(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffect
    _classid_ = 'Windows.Devices.Lights.Effects.LampArraySolidEffect'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Devices.Lights.Effects.LampArraySolidEffect.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffectFactory, lampArray: win32more.Windows.Devices.Lights.LampArray, lampIndexes: PassArray[Int32]) -> win32more.Windows.Devices.Lights.Effects.LampArraySolidEffect: ...
    @winrt_mixinmethod
    def get_Color(self: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffect) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_Color(self: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffect, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def get_Duration(self: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Duration(self: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_StartDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffect) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_StartDelay(self: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffect, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    @winrt_mixinmethod
    def get_CompletionBehavior(self: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffect) -> win32more.Windows.Devices.Lights.Effects.LampArrayEffectCompletionBehavior: ...
    @winrt_mixinmethod
    def put_CompletionBehavior(self: win32more.Windows.Devices.Lights.Effects.ILampArraySolidEffect, value: win32more.Windows.Devices.Lights.Effects.LampArrayEffectCompletionBehavior) -> Void: ...
    @winrt_mixinmethod
    def get_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect) -> Int32: ...
    @winrt_mixinmethod
    def put_ZIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayEffect, value: Int32) -> Void: ...
    Color = property(get_Color, put_Color)
    CompletionBehavior = property(get_CompletionBehavior, put_CompletionBehavior)
    Duration = property(get_Duration, put_Duration)
    StartDelay = property(get_StartDelay, put_StartDelay)
    ZIndex = property(get_ZIndex, put_ZIndex)
class LampArrayUpdateRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Lights.Effects.ILampArrayUpdateRequestedEventArgs
    _classid_ = 'Windows.Devices.Lights.Effects.LampArrayUpdateRequestedEventArgs'
    @winrt_mixinmethod
    def get_SinceStarted(self: win32more.Windows.Devices.Lights.Effects.ILampArrayUpdateRequestedEventArgs) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def SetColor(self: win32more.Windows.Devices.Lights.Effects.ILampArrayUpdateRequestedEventArgs, desiredColor: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def SetColorForIndex(self: win32more.Windows.Devices.Lights.Effects.ILampArrayUpdateRequestedEventArgs, lampIndex: Int32, desiredColor: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def SetSingleColorForIndices(self: win32more.Windows.Devices.Lights.Effects.ILampArrayUpdateRequestedEventArgs, desiredColor: win32more.Windows.UI.Color, lampIndexes: PassArray[Int32]) -> Void: ...
    @winrt_mixinmethod
    def SetColorsForIndices(self: win32more.Windows.Devices.Lights.Effects.ILampArrayUpdateRequestedEventArgs, desiredColors: PassArray[win32more.Windows.UI.Color], lampIndexes: PassArray[Int32]) -> Void: ...
    SinceStarted = property(get_SinceStarted, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Direct3D
import win32more.Windows.Win32.Graphics.Direct3D11
import win32more.Windows.Win32.Graphics.Direct3D11on12
import win32more.Windows.Win32.Graphics.Direct3D12
import win32more.Windows.Win32.System.Com
@winfunctype('d3d11.dll')
def D3D11On12CreateDevice(pDevice: win32more.Windows.Win32.System.Com.IUnknown, Flags: UInt32, pFeatureLevels: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), FeatureLevels: UInt32, ppCommandQueues: POINTER(win32more.Windows.Win32.System.Com.IUnknown), NumQueues: UInt32, NodeMask: UInt32, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device), ppImmediateContext: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext), pChosenFeatureLevel: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class D3D11_RESOURCE_FLAGS(Structure):
    BindFlags: UInt32
    MiscFlags: UInt32
    CPUAccessFlags: UInt32
    StructureByteStride: UInt32
class ID3D11On12Device(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{85611e73-70a9-490e-9614-a9e302777904}')
    @commethod(3)
    def CreateWrappedResource(self, pResource12: win32more.Windows.Win32.System.Com.IUnknown, pFlags11: POINTER(win32more.Windows.Win32.Graphics.Direct3D11on12.D3D11_RESOURCE_FLAGS), InState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES, OutState: win32more.Windows.Win32.Graphics.Direct3D12.D3D12_RESOURCE_STATES, riid: POINTER(Guid), ppResource11: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReleaseWrappedResources(self, ppResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource), NumResources: UInt32) -> Void: ...
    @commethod(5)
    def AcquireWrappedResources(self, ppResources: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource), NumResources: UInt32) -> Void: ...
class ID3D11On12Device1(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11on12.ID3D11On12Device
    _iid_ = Guid('{bdb64df4-ea2f-4c70-b861-aaab1258bb5d}')
    @commethod(6)
    def GetD3D12Device(self, riid: POINTER(Guid), ppvDevice: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ID3D11On12Device2(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D11on12.ID3D11On12Device1
    _iid_ = Guid('{dc90f331-4740-43fa-866e-67f12cb58223}')
    @commethod(7)
    def UnwrapUnderlyingResource(self, pResource11: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, pCommandQueue: win32more.Windows.Win32.Graphics.Direct3D12.ID3D12CommandQueue, riid: POINTER(Guid), ppvResource12: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def ReturnUnderlyingResource(self, pResource11: win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Resource, NumSync: UInt32, pSignalValues: POINTER(UInt64), ppFences: POINTER(win32more.Windows.Win32.Graphics.Direct3D12.ID3D12Fence)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def PFN_D3D11ON12_CREATE_DEVICE(param0: win32more.Windows.Win32.System.Com.IUnknown, param1: UInt32, param2: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL), FeatureLevels: UInt32, param4: POINTER(win32more.Windows.Win32.System.Com.IUnknown), NumQueues: UInt32, param6: UInt32, param7: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11Device), param8: POINTER(win32more.Windows.Win32.Graphics.Direct3D11.ID3D11DeviceContext), param9: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3D_FEATURE_LEVEL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)
